
.panel-body label, .form-group label {
  color: black;
}

.panel-body .form-control-static {
  color: black;
}
.deformClosebutton {
  margin-right: 3px;
}

.list-grid {
  color: #42325b;
}

.deformFileupload span, .deformFileupload input[type=file] {
  color: #000000;
}

.deformFileupload .deformReplaces {
  float: none;
}

.wizard > .content > .body div.ol-attribution > ul > li {
  display: inline;
  padding: 0;
}

/* Typeahead's dropdown meny */
.tt-dropdown-menu {
  color: black;
}

/*
 * Grid
 */
#grid {
  table-layout: auto;
}
.bootstrap-table {
  white-space: nowrap;
}
.bootstrap-table .fixed-table-toolbar .dropdown-menu {
  min-width: 200px;
}

/*
 * Form
 */
.form-panel > .panel-footer {
  position:sticky;
  bottom: 0;
}
